import React from 'react'
import { translate } from 'cozy-ui/react/I18n'

import StyledBorderCard from 'components/CommonKit/Card/StyledBorderCard'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'

import GreenIndicatorIcon from 'assets/icons/visu/indicator/green.svg'
import RedIndicatorIcon from 'assets/icons/visu/indicator/red.svg'
import GreyIndicatorIcon from 'assets/icons/visu/indicator/grey.svg'
import ErrorIndicatorIcon from 'assets/icons/visu/indicator/error.svg'
import NodataIndicatorIcon from 'assets/icons/visu/indicator/nodata.svg'
import {
  IPerformanceIndicator,
  TimeStep,
} from 'services/dataConsumptionContracts'
import { formatNumberValues } from 'utils/utils'

interface PerformanceIndicatorProps {
  t: Function
  performanceIndicator: IPerformanceIndicator
  timePeriodText: string
  timeStep: TimeStep
}

const PerformanceIndicator: React.FC<PerformanceIndicatorProps> = ({
  t,
  performanceIndicator,
  timePeriodText,
  timeStep,
}: PerformanceIndicatorProps) => {
  let displayedValue: string
  if (performanceIndicator && performanceIndicator.value)
    displayedValue = formatNumberValues(performanceIndicator.value).toString()
  else displayedValue = '-----'

  let errorInPerf = false
  if (performanceIndicator && !performanceIndicator.value) {
    errorInPerf = true
  }

  let perf: number | null = null
  if (
    performanceIndicator &&
    performanceIndicator.value &&
    performanceIndicator.compareValue
  ) {
    perf =
      100 * (performanceIndicator.value / performanceIndicator.compareValue - 1)
  }
  const perfString = perf ? formatNumberValues(perf) : ''

  let perfStatus = ['error', ErrorIndicatorIcon]
  if (perf === null && !errorInPerf)
    perfStatus = ['nodata', NodataIndicatorIcon]
  else if (perf === null && errorInPerf)
    perfStatus = ['error', ErrorIndicatorIcon]
  else if (perf && perf === 0) perfStatus = ['zero', GreyIndicatorIcon]
  else if (perf && perf > 0) perfStatus = ['positive', RedIndicatorIcon]
  else if (perf && perf < 0) perfStatus = ['negative', GreenIndicatorIcon]

  const getRelevantFrequencyLabel = (timeStep: TimeStep) => {
    let frequency = 'COMMON.'
    switch (timeStep) {
      case TimeStep.HALF_AN_HOUR:
        frequency += 'DAILY_FRENQUENCY'
        break

      case TimeStep.HOUR:
        frequency += 'DAILY_FRENQUENCY'
        break

      case TimeStep.DAY:
        frequency += 'WEEKLY_FRENQUENCY'
        break

      case TimeStep.MONTH:
        frequency += 'MONTHLY_FRENQUENCY'
        break

      case TimeStep.YEAR:
        frequency += 'YEARLY_FRENQUENCY'
        break

      default:
        return ''
    }

    return frequency
  }

  return (
    <StyledBorderCard>
      <div className="fpi">
        <div className="fpi-left">
          <div className="fpi-title card-title-on">
            {t('COMMON.PERF_INDICATOR_LABEL')}{' '}
            {t(getRelevantFrequencyLabel(timeStep))}
          </div>
          <div className="fpi-content">
            <StyledIcon
              className="fpi-content-icon"
              icon={perfStatus[1]}
              size={50}
            />
            <div className="fpi-content-perf">
              <div className="fpi-content-perf-result card-result">
                <span>{displayedValue}</span>
                <span className="card-indicator">€</span>
              </div>
              {perfStatus[0] === 'positive' ||
              perfStatus[0] === 'negative' ||
              perfStatus[0] === 'zero' ? (
                <div className="fpi-content-perf-indicator card-text">
                  <span
                    className={`fpi-content-perf-indicator-kpi ${perfStatus[0]} card-text-bold`}
                  >
                    {perfStatus[0] === 'positive' ? '+' : ''}
                    {perfString}%
                  </span>
                  <span> / {timePeriodText}</span>
                </div>
              ) : (
                <div className="fpi-content-perf-indicator card-text">
                  <div> {t('INDICATOR.ERROR_NO_COMPARE')} </div>
                  <div> {t('INDICATOR.ERROR_NO_COMPARE_REASON')} </div>
                </div>
              )}
            </div>
          </div>
        </div>
        <div className="fpi-right"></div>
      </div>
    </StyledBorderCard>
  )
}

export default translate()(PerformanceIndicator)
